@@ -22,15 +22,14 @@
 #include <kpluginfactory.h>
 #include <kpluginloader.h>
 
-K_PLUGIN_FACTORY( AkonadiConfigModuleFactory, registerPlugin<AkonadiConfigModule>(); )
-K_EXPORT_PLUGIN( AkonadiConfigModuleFactory( "kcm_akonadi" ) )
-
-AkonadiConfigModule::AkonadiConfigModule( QWidget * parent, const QVariantList & args ) :
-    KCModuleContainer( parent )
+K_PLUGIN_FACTORY(AkonadiConfigModuleFactory, registerPlugin<AkonadiConfigModule>();)
+AkonadiConfigModule::AkonadiConfigModule(QWidget *parent, const QVariantList &args) :
+    KCModuleContainer(parent)
 {
-  Q_UNUSED( args );
-  setButtons( KCModule::Default | KCModule::Apply );
-  addModule( QLatin1String( "kcm_akonadi_resources" ) );
-  addModule( QLatin1String( "kcm_akonadi_server" ) );
+    Q_UNUSED(args);
+    setButtons(KCModule::Default | KCModule::Apply);
+    addModule(QStringLiteral("kcm_akonadi_resources"));
+    addModule(QStringLiteral("kcm_akonadi_server"));
 }
 
+#include "akonadiconfigmodule.moc"
