@@ -32,21 +32,21 @@
  */
 class DavCollectionsFetchJob : public KJob
 {
-  Q_OBJECT
+    Q_OBJECT
 
-  public:
+public:
     /**
      * Creates a new dav collections fetch job.
      *
      * @param url The DAV url of the DAV collection whose sub collections shall be fetched.
      * @param parent The parent object.
      */
-    explicit DavCollectionsFetchJob( const DavUtils::DavUrl &url, QObject *parent = 0 );
+    explicit DavCollectionsFetchJob(const DavUtils::DavUrl &url, QObject *parent = Q_NULLPTR);
 
     /**
      * Starts the job.
      */
-    virtual void start();
+    void start() Q_DECL_OVERRIDE;
 
     /**
      * Returns the list of fetched DAV collections.
@@ -58,21 +58,21 @@ class DavCollectionsFetchJob : public KJob
      */
     DavUtils::DavUrl davUrl() const;
 
-  Q_SIGNALS:
+Q_SIGNALS:
     /**
      * This signal is emitted every time a new collection has been discovered.
      *
      * @param collectionUrl The URL of the discovered collection
      * @param configuredUrl The URL given to the job
      */
-    void collectionDiscovered( int protocol, const QString &collectionUrl, const QString &configuredUrl );
+    void collectionDiscovered(int protocol, const QString &collectionUrl, const QString &configuredUrl);
 
-  private Q_SLOTS:
-    void principalFetchFinished( KJob* );
-    void collectionsFetchFinished( KJob* );
+private Q_SLOTS:
+    void principalFetchFinished(KJob *);
+    void collectionsFetchFinished(KJob *);
 
-  private:
-    void doCollectionsFetch( const KUrl &url );
+private:
+    void doCollectionsFetch(const KUrl &url);
     void subjobFinished();
 
     DavUtils::DavUrl mUrl;
